summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteaccountmanager.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
commit47c8a359c5276062c4bc17f0e82410f29081b502 (patch)
tree2d54a5f60a5b74067632f9ef6df58c2bc38155e6 /kopete/libkopete/kopeteaccountmanager.h
parent6f82532777a35e0e60bbd2b290b2e93e646f349b (diff)
downloadtdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.tar.gz
tdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1157648 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/libkopete/kopeteaccountmanager.h')
-rw-r--r--kopete/libkopete/kopeteaccountmanager.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/kopete/libkopete/kopeteaccountmanager.h b/kopete/libkopete/kopeteaccountmanager.h
index ed0c939a..75ebf667 100644
--- a/kopete/libkopete/kopeteaccountmanager.h
+++ b/kopete/libkopete/kopeteaccountmanager.h
@@ -19,9 +19,9 @@
#ifndef __kopeteaccountmanager_h__
#define __kopeteaccountmanager_h__
-#include <qobject.h>
-#include <qptrlist.h>
-#include <qdict.h>
+#include <tqobject.h>
+#include <tqptrlist.h>
+#include <tqdict.h>
#include "kopete_export.h"
@@ -65,16 +65,16 @@ public:
* \brief Retrieve the list of accounts
* \return a list of all the accounts
*/
- const QPtrList<Account> & accounts() const;
+ const TQPtrList<Account> & accounts() const;
/**
* \brief Retrieve a QDict of accounts for the given protocol
*
* The list is guaranteed to contain only accounts for the specified
* protocol
* \param p is the Protocol object you want accounts for
*/
- QDict<Account> accounts( const Protocol *p ) const;
+ TQDict<Account> accounts( const Protocol *p ) const;
/**
* \brief Return the account asked
@@ -82,7 +82,7 @@ public:
* \param accountId is the ID for the account you want
* \return the Account object found or NULL if no account was found
*/
- Account* findAccount( const QString &protocolId, const QString &accountId );
+ Account* findAccount( const TQString &protocolId, const TQString &accountId );
/**
* \brief Delete the account and clean the config data
@@ -97,7 +97,7 @@ public:
* Guesses a color for the next account of a given protocol based on the already registered colors
* \return the color guessed for the account
*/
- QColor guessColor( Protocol *protocol ) const ;
+ TQColor guessColor( Protocol *protocol ) const ;
/**
* @brief Register the account.
@@ -142,7 +142,7 @@ public slots:
* @param flags is a bitmask of SetOnlineStatusFlag
*/
void setOnlineStatus( /*Kopete::OnlineStatusManager::Categories*/ uint category,
- const QString& awayMessage = QString::null, uint flags=0);
+ const TQString& awayMessage = TQString::null, uint flags=0);
/**
* \brief Set all accounts to away at once.
@@ -152,7 +152,7 @@ public slots:
* @param awayReason is the away message that will be set.
* @param away decides whether the message is away/non-away
*/
- void setAwayAll( const QString &awayReason = QString::null, bool away=true );
+ void setAwayAll( const TQString &awayReason = TQString::null, bool away=true );
/**
* \brief Connect or make available every account.
@@ -162,7 +162,7 @@ public slots:
* This is a slot, so you can connect directly to it from e.g. a KAction.
* @param awayReason is the away(status) message that will be set.
*/
- void setAvailableAll( const QString &awayReason = QString::null );
+ void setAvailableAll( const TQString &awayReason = TQString::null );
/**
* \internal
@@ -65,16 +65,16 @@ public:
/**
- * \brief Retrieve a QDict of accounts for the given protocol
+ * \brief Retrieve a TQDict of accounts for the given protocol
*
* The list is guaranteed to contain only accounts for the specified